import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class TransactionService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all transactions
     * Get all transaction requests.
     * @param status The status to query: 'queued', 'mined', 'errored', or 'cancelled'. Default: 'queued'
     * @param page Specify the page number.
     * @param limit Specify the number of results to return per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(status: ('queued' | 'mined' | 'cancelled' | 'errored'), page?: number, limit?: number): CancelablePromise<{
        result: {
            transactions: Array<{
                queueId: (string | null);
                /**
                 * The current state of the transaction.
                 */
                status: ('queued' | 'sent' | 'mined' | 'errored' | 'cancelled');
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | string | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                /**
                 * The number of retry attempts
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                accountSalt: (string | null);
                accountFactoryAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
                onChainTxStatus: (number | null);
                onchainStatus: ('success' | 'reverted' | null);
                effectiveGasPrice: (string | null);
                cumulativeGasUsed: (string | null);
            }>;
            totalCount: number;
        };
    }>;
    /**
     * Get transaction status
     * Get the status for a transaction request.
     * @param queueId Transaction queue ID
     * @returns any Default Response
     * @throws ApiError
     */
    status(queueId: string): CancelablePromise<{
        result: {
            queueId: (string | null);
            /**
             * The current state of the transaction.
             */
            status: ('queued' | 'sent' | 'mined' | 'errored' | 'cancelled');
            chainId: (string | null);
            fromAddress: (string | null);
            toAddress: (string | null);
            data: (string | null);
            extension: (string | null);
            value: (string | null);
            nonce: (number | string | null);
            gasLimit: (string | null);
            gasPrice: (string | null);
            maxFeePerGas: (string | null);
            maxPriorityFeePerGas: (string | null);
            transactionType: (number | null);
            transactionHash: (string | null);
            queuedAt: (string | null);
            sentAt: (string | null);
            minedAt: (string | null);
            cancelledAt: (string | null);
            deployedContractAddress: (string | null);
            deployedContractType: (string | null);
            errorMessage: (string | null);
            sentAtBlockNumber: (number | null);
            blockNumber: (number | null);
            /**
             * The number of retry attempts
             */
            retryCount: number;
            retryGasValues: (boolean | null);
            retryMaxFeePerGas: (string | null);
            retryMaxPriorityFeePerGas: (string | null);
            signerAddress: (string | null);
            accountAddress: (string | null);
            accountSalt: (string | null);
            accountFactoryAddress: (string | null);
            target: (string | null);
            sender: (string | null);
            initCode: (string | null);
            callData: (string | null);
            callGasLimit: (string | null);
            verificationGasLimit: (string | null);
            preVerificationGas: (string | null);
            paymasterAndData: (string | null);
            userOpHash: (string | null);
            functionName: (string | null);
            functionArgs: (string | null);
            onChainTxStatus: (number | null);
            onchainStatus: ('success' | 'reverted' | null);
            effectiveGasPrice: (string | null);
            cumulativeGasUsed: (string | null);
        };
    }>;
    /**
     * Get all deployment transactions
     * Get all transaction requests to deploy contracts.
     * @param page Specify the page number for pagination.
     * @param limit Specify the number of transactions to return per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAllDeployedContracts(page?: number, limit?: number): CancelablePromise<{
        result: {
            transactions: Array<{
                queueId: (string | null);
                /**
                 * The current state of the transaction.
                 */
                status: ('queued' | 'sent' | 'mined' | 'errored' | 'cancelled');
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | string | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                /**
                 * The number of retry attempts
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                accountSalt: (string | null);
                accountFactoryAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
                onChainTxStatus: (number | null);
                onchainStatus: ('success' | 'reverted' | null);
                effectiveGasPrice: (string | null);
                cumulativeGasUsed: (string | null);
            }>;
            totalCount: number;
        };
    }>;
    /**
     * Retry transaction (synchronous)
     * Retry a transaction with updated gas settings. Blocks until the transaction is mined or errors.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    syncRetry(requestBody: {
        /**
         * Transaction queue ID
         */
        queueId: string;
        maxFeePerGas?: string;
        maxPriorityFeePerGas?: string;
    }): CancelablePromise<{
        result: {
            /**
             * A transaction hash
             */
            transactionHash: string;
        };
    }>;
    /**
     * Retry failed transaction
     * Retry a failed transaction
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    retryFailed(requestBody: {
        /**
         * Transaction queue ID
         */
        queueId: string;
    }): CancelablePromise<{
        result: {
            message: string;
            status: string;
        };
    }>;
    /**
     * Cancel transaction
     * Attempt to cancel a transaction by sending a null transaction with a higher gas setting. This transaction is not guaranteed to be cancelled.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    cancel(requestBody: {
        /**
         * Transaction queue ID
         */
        queueId: string;
    }): CancelablePromise<{
        result: {
            /**
             * Transaction queue ID
             */
            queueId: string;
            /**
             * Response status
             */
            status: string;
            /**
             * Response message
             */
            message: string;
            /**
             * A transaction hash
             */
            transactionHash?: string;
        };
    }>;
    /**
     * Send a signed transaction
     * Send a signed transaction
     * @param chain Chain ID
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    sendRawTransaction(chain: string, requestBody: {
        signedTransaction: string;
    }): CancelablePromise<{
        result: {
            /**
             * A transaction hash
             */
            transactionHash: string;
        };
    }>;
    /**
     * Send a signed user operation
     * Send a signed user operation
     * @param chain Chain ID
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    sendSignedUserOp(chain: string, requestBody: {
        signedUserOp: any;
    }): CancelablePromise<({
        result: {
            /**
             * A transaction hash
             */
            userOpHash: string;
        };
    } | {
        error: {
            message: string;
        };
    })>;
    /**
     * Get transaction receipt
     * Get the transaction receipt from a transaction hash.
     * @param transactionHash Transaction hash
     * @param chain Chain ID or name
     * @returns any Default Response
     * @throws ApiError
     */
    getTransactionReceipt(transactionHash: string, chain: string): CancelablePromise<{
        result: ({
            to?: string;
            from?: string;
            contractAddress?: (string | null);
            transactionIndex?: number;
            root?: string;
            gasUsed?: string;
            logsBloom?: string;
            blockHash?: string;
            /**
             * A transaction hash
             */
            transactionHash?: string;
            logs?: Array<any>;
            blockNumber?: number;
            confirmations?: number;
            cumulativeGasUsed?: string;
            effectiveGasPrice?: string;
            byzantium?: boolean;
            type?: number;
            status?: number;
        } | null);
    }>;
    /**
     * Get transaction receipt from user-op hash
     * Get the transaction receipt from a user-op hash.
     * @param userOpHash User operation hash
     * @param chain Chain ID or name
     * @returns any Default Response
     * @throws ApiError
     */
    useropHashReceipt(userOpHash: string, chain: string): CancelablePromise<{
        result: any;
    }>;
    /**
     * Get transaction logs
     * Get transaction logs for a mined transaction. A tranasction queue ID or hash must be provided. Set `parseLogs` to parse the event logs.
     * @param chain Chain ID or name
     * @param queueId The queue ID for a mined transaction.
     * @param transactionHash The transaction hash for a mined transaction.
     * @param parseLogs If true, parse the raw logs as events defined in the contract ABI. (Default: true)
     * @returns any Default Response
     * @throws ApiError
     */
    getTransactionLogs(chain: string, queueId?: string, transactionHash?: string, parseLogs?: boolean): CancelablePromise<{
        result: Array<{
            /**
             * A contract or wallet address
             */
            address: string;
            topics: Array<string>;
            data: string;
            blockNumber: string;
            /**
             * A transaction hash
             */
            transactionHash: string;
            transactionIndex: number;
            blockHash: string;
            logIndex: number;
            removed: boolean;
            /**
             * Event name, only returned when `parseLogs` is true
             */
            eventName?: string;
            /**
             * Event arguments. Only returned when `parseLogs` is true
             */
            args?: any;
        }>;
    }>;
}
